# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from . import cxmate_pb2 as cxmate__pb2


class cxMateServiceStub(object):
  """********** SERVICE DEFINITION **********

  cxMateService defines a cxMate compatible service implementation
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.StreamNetworks = channel.stream_stream(
        '/proto.cxMateService/StreamNetworks',
        request_serializer=cxmate__pb2.NetworkElement.SerializeToString,
        response_deserializer=cxmate__pb2.NetworkElement.FromString,
        )


class cxMateServiceServicer(object):
  """********** SERVICE DEFINITION **********

  cxMateService defines a cxMate compatible service implementation
  """

  def StreamNetworks(self, request_iterator, context):
    """StreamNetworks transfers one or more networks to and from the service.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_cxMateServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'StreamNetworks': grpc.stream_stream_rpc_method_handler(
          servicer.StreamNetworks,
          request_deserializer=cxmate__pb2.NetworkElement.FromString,
          response_serializer=cxmate__pb2.NetworkElement.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'proto.cxMateService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from setuptools import setup, find_packages

setup(
    name='cxmate',
    version='0.7.0',
    description='SDK for creating cxMate services',
    long_description="""
    cxmate-py provides a Python SDK for interacting with [cxMate](https://github.com/ericsage/cxmate), an adapter that allows Cytoscape to talk to network services. This SDK enables quick and painless development of a cxMate service, follow the Getting Started guide to learn more about the process.
    """,
    url='https://github.com/cxmate/cxmate-py',
    author='Eric Sage, Brett Settle',
    author_email='eric.david.sage@gmail.com',
    license='MIT',
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
    ],
    keywords='cytoscape networkx network biology cxmate',
    packages=find_packages(),
    install_requires=['networkx', 'grpcio', 'futures'],
)
